

(function ($) {
    'use strict';

    //activate Tooltips
    var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'))
    var tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
      return new bootstrap.Tooltip(tooltipTriggerEl)
    })
  
    // Sticky Menu
    $(window).scroll(function () {
      if ($('.navigation').offset().top > 100) {
        $('.navigation').addClass('nav-bg');
      } else {
        $('.navigation').removeClass('nav-bg');
      }
    });
    
    // Select the progress bar and GIF elements
    const progressBar = document.getElementById('progress-bar');
    const progressGif = document.getElementById('progress-gif');

    function updateProgressBar() {
        const windowHeight = document.documentElement.clientHeight;
        const documentHeight = document.documentElement.scrollHeight - windowHeight;
        const scrollTop = document.body.scrollTop || document.documentElement.scrollTop;
        const scrollPercentage = (scrollTop / documentHeight) * 100;

        // Update progress bar width based on the scroll position
        progressBar.style.width = scrollPercentage + '%';

        const progressBarWidth = progressBar.offsetWidth;
        progressGif.style.left = (progressBarWidth - 20) + 'px';  // Adjust the '-20' value if necessary to set the GIF's position correctly on the edge.
    }

    // Add a scroll event listener to update the progress bar and GIF
    window.addEventListener('scroll', updateProgressBar);

    // team slider
    $('.team-slider').slick({
      dots: false,
      infinite: false,
      speed: 1000,
      autoplay: true,
      autoplaySpeed: 5000,
      slidesToShow: 3,
      slidesToScroll: 1,
      arrows: true,
      prevArrow: '<button type=\'button\' class=\'prevArrow\'><i class=\'ti-arrow-left\'></i></button>',
      nextArrow: '<button type=\'button\' class=\'nextArrow\'><i class=\'ti-arrow-right\'></i></button>',
      responsive: [{
          breakpoint: 1024,
          settings: {
            slidesToShow: 3,
            slidesToScroll: 1
          }
        },
        {
          breakpoint: 991,
          settings: {
            slidesToShow: 2,
            slidesToScroll: 1
          }
        },
        {
          breakpoint: 767,
          settings: {
            slidesToShow: 1,
            slidesToScroll: 1
          }
        }
      ]
    });
  
    // clients logo slider
    $('.client-logo-slider').slick({
      infinite: true,
      slidesToShow: 5,
      slidesToScroll: 1,
      autoplay: true,
      dots: false,
      arrows: false,
      responsive: [{
          breakpoint: 1024,
          settings: {
            slidesToShow: 3,
            slidesToScroll: 1
          }
        },
        {
          breakpoint: 600,
          settings: {
            slidesToShow: 3,
            slidesToScroll: 1
          }
        },
        {
          breakpoint: 480,
          settings: {
            slidesToShow: 2,
            slidesToScroll: 1
          }
        },
        {
          breakpoint: 400,
          settings: {
            slidesToShow: 1,
            slidesToScroll: 1
          }
        }
      ]
    });

    $(document).ready(function() {
      // Scrollspy functionality
      $('.additional-shape').removeClass('show');
      $(window).on('scroll', function() {
        $('.flowchart-shape').each(function() {
          if(isElementInViewport($(this))) {
            updateActiveInfoBox($(this));
          }
        });
      });
    
      // Button functionality
      $('.btn').on('click', function() {  
        var targetSelector = $(this).data('target'); 
        var $targetElement = $(targetSelector);
        updateActiveInfoBox($targetElement);
      });
    });
    
    function updateActiveInfoBox($el) {
      var relatedInfoClass = getRelatedInfoClass($el);
      $('.additional-shape.show').removeClass('show');
      $(relatedInfoClass).addClass('show');
    }
    
    function getRelatedInfoClass($el) {
      return $($el.data('target'));
    }
    
    function isElementInViewport(el) {
      var rect = el[0].getBoundingClientRect();
      return (
        rect.top >= 0 &&
        rect.left >= 0 &&
        rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) && 
        rect.right <= (window.innerWidth || document.documentElement.clientWidth)
      );
    }
     
    // sdg stagger animation
    const observer_stagger = new IntersectionObserver(entries => {
      entries.forEach((entry) => {
        console.log(entry)
        if (entry.isIntersecting) {
          entry.target.classList.add('stagger-active');
        } else {
          entry.target.classList.remove('stagger-active');
        }
      })
    });

    const staggerElements = document.querySelectorAll('.stagger');
    staggerElements.forEach((el) => observer_stagger.observe(el));


    // about video popup
    $(document).ready(function () {
      $('.venobox').venobox();
    });
  
    // animation scroll js
    var html_body = $('html, body');
    $('.page-scroll').on('click', function () { //use page-scroll class in any HTML tag for scrolling
      if (location.pathname.replace(/^\//, '') === this.pathname.replace(/^\//, '') && location.hostname === this.hostname) {
        var target = $(this.hash);
        target = target.length ? target : $('[name=' + this.hash.slice(1) + ']');
        if (target.length) {
          html_body.animate({
            scrollTop: target.offset().top - 50
          }, 1500, 'easeInOutExpo');
          return false;
        }
      }
    });
  
    // easeInOutExpo Declaration
    jQuery.extend(jQuery.easing, {
      easeInOutExpo: function (x, t, b, c, d) {
        if (t === 0) {
          return b;
        }
        if (t === d) {
          return b + c;
        }
        if ((t /= d / 2) < 1) {
          return c / 2 * Math.pow(2, 10 * (t - 1));
        } + b;
        return c / 2 * (-Math.pow(2, -10 * --t) + 2) + b;
      }
    });
    
    //sdgs interaction
    $(document).ready(function(){
      function activateInfo(infoId, navId) {
          $('.info-content').hide();
          $(infoId).show();
          $('.info-content').removeClass('show');
          $(infoId).addClass('show');
          $('.active').removeClass('active');
          $(navId).addClass('active');
      }
  
      $("#sdg-img1").click(function(){
          activateInfo("#info1", "#nav-sdg12");
      });
      $("#sdg-img2").click(function(){
          activateInfo("#info2", "#nav-sdg11");
      });
      $("#sdg-img3").click(function(){
          activateInfo("#info3", "#nav-sdg9");
      });
      $("#sdg-img4").click(function(){
          activateInfo("#info4", "#nav-sdg13");
      });
      $("#nav-sdg12").click(function(){
          activateInfo("#info1", "#nav-sdg12");
      });
      $("#nav-sdg11").click(function(){
          activateInfo("#info2", "#nav-sdg11");
       });
      $("#nav-sdg9").click(function(){
          activateInfo("#info3", "#nav-sdg9");
      });
      $("#nav-sdg13").click(function(){
          activateInfo("#info4", "#nav-sdg13");
      });
      $("#side-sdg12").click(function(){
        activateInfo("#info1", "#nav-sdg12");
      });
      $("#side-sdg11").click(function(){
          activateInfo("#info2", "#nav-sdg11");
      });
      $("#side-sdg9").click(function(){
          activateInfo("#info3", "#nav-sdg9");
      });
      $("#side-sdg13").click(function(){
          activateInfo("#info4", "#nav-sdg13");
      });
  
      // Trigger click event for the first image
      $('#sdg-img3').trigger('click');
        // Logik für Sticky-Karten
      var stickyStart = $('.card-group').offset().top + 395;
      var stickyEnd = $('.gps-container').offset().top -200;
      $(window).on("scroll", function() {
        console.log("blabl");
        if ((window.pageYOffset) >= stickyStart) {
          $('.flex-card-container').addClass('sticky-at-top');
          $('.flex-card-container').show();
        } else {
          $('.flex-card-container').removeClass('sticky-at-top');
          $('.flex-card-container').show();
        }
        if ((window.pageYOffset) >= stickyEnd) {
          $('.flex-card-container').hide();
        }
      });
  });

    //Scrolling Trigger
    const left = document.querySelectorAll('.description-left');
    const right = document.querySelectorAll('.description-right');
    const center = document.querySelectorAll('.home-seccenter');
    const allcenter = document.querySelectorAll('.all-seccenter');
    const counterObserver = document.querySelectorAll('.counter');
  
    const options = {
      root: null,
      rootMargin: '0px',
      thershold:.4
    }
  
    const callbacksleft = (entries) => {
      entries.forEach(entry => {
        if (entry.isIntersecting){
          entry.target.classList.add('animation-left');
          return;
        }
        entry.target.classList.remove('animation-left');
      })
    }
  
    const callbacksright = (entries) => {
      entries.forEach(entry => {
        if (entry.isIntersecting){
          entry.target.classList.add('animation-right');
          return;
        }
        entry.target.classList.remove('animation-right');
      })
    }

    const callbackscenter = (entries) => {
      entries.forEach(entry => {
        if (entry.isIntersecting){
          entry.target.classList.add('animation-center');
          return;
        }
        entry.target.classList.remove('animation-center');
      })
    }

    const callbacksallcenter = (entries) => {
      entries.forEach(entry => {
        if (entry.isIntersecting){
          entry.target.classList.add('all-center');
          return;
        }
        entry.target.classList.remove('all-center');
      })
    }

    const callbackscounter = (entries) => {
      entries.forEach(entry => {
        if (entry.isIntersecting){
          incEltNbr("nmbr");
          return;
        }
      })
    }
  
    let observerleft = new IntersectionObserver(callbacksleft, options);
    left.forEach(element => {
    observerleft.observe(element);
    });
  
    let observerright = new IntersectionObserver(callbacksright, options);
    right.forEach(element => {
    observerright.observe(element);
    });

    let observercenter = new IntersectionObserver(callbackscenter, options);
    center.forEach(element => {
    observercenter.observe(element);
    });

    let observerallcenter = new IntersectionObserver(callbacksallcenter, options);
    allcenter.forEach(element => {
    observerallcenter.observe(element);
    });

    let observercounter = new IntersectionObserver(callbackscounter, options);
    counterObserver.forEach(element => {
    observercounter.observe(element);
    });
    
    /*incEltNbr("nmbr"); /*Call this funtion with the ID-name for that element to increase the number within*/
  
  })(jQuery);

/* Script for Counter */
    var speed = 30;

function numberWithCommas(x) {
  return (x + "" ).replace(/\B(?=(\d{3})+(?!\d))/g, ",");
s}
    

/* Call this function with a string containing the ID name to
 * the element containing the number you want to do a count animation on.*/
function incEltNbr(id) {
  elt = document.getElementById(id);
  endNbr = Number(document.getElementById(id).innerHTML);
  incNbrRec(400000000, endNbr, elt);
}

/*A recursive function to increase the number.*/
function incNbrRec(i, endNbr, elt) {
  if (i <= endNbr) {
    elt.innerHTML = i;
    setTimeout(function() {//Delay a bit before calling the function again.
      numberWithCommas(incNbrRec(i + 1875000, endNbr, elt));
    }, speed);
  }
}


LottieInteractivity.create({
  player:'#firstLottie',
  mode:"scroll",
      actions: [
        {
          visibility:[0, 0.3],
          type: "stop",
          frames: [0]
        },
        {
            visibility:[0.3, 0.9],
            type: "seek",
            frames: [0, 150],
        },
        {
            visibility:[0.9, 1.0],
            type: "stop",
            frames: [150],
        },
      ]
  });

    //navbar icon resize
$(document).ready(function () {
  $(document).on("click", ".navbar-toggler", function () {
    if ($(window).width() < 576) {
      $("nav .dropdown-icon-wrapper svg")
        .addClass("fa-xl")
        .removeClass("fa-2xl");
    } else {
      $("nav .dropdown-icon-wrapper svg")
        .addClass("fa-2xl")
        .removeClass("fa-xl");
    }
  });
});


$(".container.mw-100").click(function (event) {
  var clickover = $(event.target);
  var $navbar = $(".navbar-collapse");               
  var _opened = $navbar.hasClass("show");
  if (_opened === true && !clickover.hasClass("navbar-toggle")) {      
      $navbar.collapse('hide');
  }
});

