let Engine = Matter.Engine,
    Render = Matter.Render,
    Runner = Matter.Runner,
    Bodies = Matter.Bodies,
    Composite = Matter.Composite,
    Composites = Matter.Composites,
    Constraint = Matter.Constraint,
    Mouse = Matter.Mouse,
    MouseConstraint = Matter.MouseConstraint,
    Events = Matter.Events;

let engine;
let render;
let runner;
let wallDown;
let wallRight;
let wallLeft;
let wallUp;

let wallsAlreadyClicked = false;

const sceneHeight = window.innerHeight*1.5;
const sceneWidth = window.innerWidth;
const particleSize = 50;
const particleSpeed = 2;
const particles1 = new Array();
const particles2 = new Array();
const particles3 = new Array();
const particles4 = new Array();
const particles5 = new Array();
const particles6 = new Array();
const particleOptions1 = {
  restitution: 0.2,
  friction: 0,
  frictionAir: 0,
  render: {
    sprite: {
      texture: 'https://static.igem.wiki/teams/4757/wiki/sack2.png',
      xScale: 0.22124,
      yScale: 0.22124
    }
  }
};
const particleOptions2 = {
  restitution: 0.2,
  friction: 0,
  frictionAir: 0,
  render: {
    sprite: {
      texture: 'https://static.igem.wiki/teams/4757/wiki/duck.png',
      xScale: 0.4,
      yScale: 0.4
    }
  }
};
const particleOptions3 = {
  restitution: 0.2,
  friction: 0,
  frictionAir: 0,
  render: {
    sprite: {
      texture: 'https://static.igem.wiki/teams/4757/wiki/flasche.png',
      xScale: 0.545,
      yScale: 0.545
    }
  }
};
const particleOptions4 = {
  restitution: 0.2,
  friction: 0,
  frictionAir: 0,
  render: {
    sprite: {
      texture: 'https://static.igem.wiki/teams/4757/wiki/milkbottle.png',
      xScale: 0.03272,
      yScale: 0.03272
    }
  }
};
const particleOptions5 = {
  restitution: 0.2,
  friction: 0,
  frictionAir: 0,
  render: {
    sprite: {
      texture: 'https://static.igem.wiki/teams/4757/wiki/toothbrush.png',
      xScale: 0.102,
      yScale: 0.102
    }
  }
};
const particleOptions6 = {
  restitution: 0.2,
  friction: 0,
  frictionAir: 0,
  render: {
    sprite: {
      texture: 'https://static.igem.wiki/teams/4757/wiki/shampooflasche.png',
      xScale: 0.392,
      yScale: 0.392
    }
  }
};



window.addEventListener("scroll", (event) => {
  activateGravity();
  secondStage();
})

function init() {
  popUpMedals();

  setup();
  createWalls();
  simulation();
}

function popUpMedals() {
  var myModal = new bootstrap.Modal(document.getElementById('awardsModal'), {
    keyboard: true
  })

  myModal.show()
}

function setup() {
    // create an engine
    engine = Engine.create();
    engine.world.gravity.y = 0;



    // create a renderer
    render = Render.create({
    element: document.getElementById("areaToRender"),
    engine: engine,
    options: {
    width: sceneWidth,
    height: sceneHeight,
    pixelRatio: 1,
    background: 'rgba(0, 0, 0, 0)',
    wireframes: false // <-- important
    }
    });

    // run the renderer
    Render.run(render);

    // create runner
    runner = Runner.create();

    // run the engine
    Runner.run(runner, engine);

    //add mouse constrait
    Composite.add(engine.world, [MouseConstraint]);
    Engine.update(engine);
}

function simulation() {
    // add mouse control
    let mouse = Mouse.create(render.canvas),
        mouseConstraint = MouseConstraint.create(engine, {
        mouse: mouse,
        constraint: {
        stiffness: 0.6,
        render: {
        visible: false
      }
 }
 });
mouseConstraint.mouse.element.removeEventListener("mousewheel", mouseConstraint.mouse.mousewheel);
mouseConstraint.mouse.element.removeEventListener("DOMMouseScroll", mouseConstraint.mouse.mousewheel);
    // create particles;
    // Trashbag
    for (let index = 0; index < 6; index++) {
      particles1[index] = Bodies.circle(Math.random() * sceneWidth, Math.random() * window.innerHeight, particleSize, particleOptions1);
      const direction = Math.random() * Math.PI * 2;
      Matter.Body.setVelocity(particles1[index], {
        x: Math.sin(direction) * particleSpeed,
        y: Math.cos(direction) * particleSpeed
      });
      Matter.Body.setInertia(particles1[index], 10000);
      // add all of the bodies to the world
      console.log(particles1[index])
      Composite.add(engine.world, [particles1[index], mouseConstraint]);
      Engine.update(engine);
    }

    //Duck.png
    for (let index = 0; index < 6; index++) {
      particles2[index] = Bodies.rectangle(Math.random() * sceneWidth, Math.random() * window.innerHeight, 88.8, 86.8, particleOptions2);;
      const direction = Math.random() * Math.PI * 2;
      Matter.Body.setVelocity(particles2[index], {
        x: Math.sin(direction) * particleSpeed,
        y: Math.cos(direction) * particleSpeed
      });
      Matter.Body.setInertia(particles2[index], 10000);
      // add all of the bodies to the world
      Composite.add(engine.world, [particles2[index], mouseConstraint]);
      Engine.update(engine);
    }

    //Flasche.png
    for (let index = 0; index < 3; index++) {
      particles3[index] = Bodies.rectangle(Math.random() * sceneWidth, Math.random() * window.innerHeight, 60, 153.3, particleOptions3);;
      const direction = Math.random() * Math.PI * 2;
      Matter.Body.setVelocity(particles3[index], {
        x: Math.sin(direction) * particleSpeed,
        y: Math.cos(direction) * particleSpeed
      });
      Matter.Body.setInertia(particles3[index], 10000);
      // add all of the bodies to the world
      Composite.add(engine.world, [particles3[index], mouseConstraint]);
      Engine.update(engine);
    }

    //milkbottle.png
    for (let index = 0; index < 3; index++) {
      particles4[index] = Bodies.rectangle(Math.random() * sceneWidth, Math.random() * window.innerHeight, 50, 95.1, particleOptions4);;
      const direction = Math.random() * Math.PI * 2;
      Matter.Body.setVelocity(particles4[index], {
        x: Math.sin(direction) * particleSpeed,
        y: Math.cos(direction) * particleSpeed
      });
      Matter.Body.setInertia(particles4[index], 10000);
      // add all of the bodies to the world
      Composite.add(engine.world, [particles4[index], mouseConstraint]);
      Engine.update(engine);
    }

    //toothbrush
    for (let index = 0; index < 6; index++) {
      particles5[index] = Bodies.rectangle(Math.random() * sceneWidth, Math.random() * window.innerHeight, 80, 26.8, particleOptions5);;
      const direction = Math.random() * Math.PI * 2;
      Matter.Body.setVelocity(particles5[index], {
        x: Math.sin(direction) * particleSpeed,
        y: Math.cos(direction) * particleSpeed
      });
      Matter.Body.setInertia(particles5[index], 10000);
      // add all of the bodies to the world
      Composite.add(engine.world, [particles5[index], mouseConstraint]);
      Engine.update(engine);
    }

    //shampooflasche
    for (let index = 0; index < 6; index++) {
      particles6[index] = Bodies.rectangle(Math.random() * sceneWidth, Math.random() * window.innerHeight, 60, 98.82, particleOptions6);;
      const direction = Math.random() * Math.PI * 2;
      Matter.Body.setVelocity(particles6[index], {
        x: Math.sin(direction) * particleSpeed,
        y: Math.cos(direction) * particleSpeed
      });
      Matter.Body.setInertia(particles6[index], 10000);
      // add all of the bodies to the world
      Composite.add(engine.world, [particles6[index], mouseConstraint]);
      Engine.update(engine);
    }

    /*
    for (let i = 0; i < 25; i++) {
      let particle = Bodies.circle(Math.random() * sceneWidth, Math.random() * sceneHeight, particleSize, particleOptions1);
      const direction = Math.random() * Math.PI * 2;
      Matter.Body.setVelocity(particle, {
        x: Math.sin(direction) * particleSpeed,
        y: Math.cos(direction) * particleSpeed
      });
      Matter.Body.setInertia(particle, 10000);
      // add all of the bodies to the world
      Composite.add(engine.world, [particle, mouseConstraint]);
      Engine.update(engine);
    }

    for (let i = 0; i < 25; i++) {
      let particle = Bodies.rectangle(Math.random() * sceneWidth, Math.random() * sceneHeight, 50, 91.53653, particleOptions2);
      const direction = Math.random() * Math.PI * 2;
      Matter.Body.setVelocity(particle, {
        x: Math.sin(direction) * particleSpeed,
        y: Math.cos(direction) * particleSpeed
      });
      Matter.Body.setInertia(particle, 10000);
      // add all of the bodies to the world
      Composite.add(engine.world, [particle, mouseConstraint]);
      Engine.update(engine);
    }
    */


   }

function createWalls() {
  wallRight = Bodies.rectangle(sceneWidth, sceneHeight/2, 20, sceneHeight, {isStatic: true, render: {fillStyle: 'rgba(0, 0, 0, 0)',}});
  wallLeft = Bodies.rectangle(1, sceneHeight/2, 20, sceneHeight, {isStatic: true, render: {fillStyle: 'rgba(0, 0, 0, 0)',}});
  wallDown = Bodies.rectangle(sceneWidth/2, window.innerHeight-100, sceneWidth, 20, {isStatic: true, render: {fillStyle: 'rgba(0, 0, 0, 0)',}});
  wallUp = Bodies.rectangle(sceneWidth/2, 1, sceneWidth, 20, {isStatic: true, render: {fillStyle: 'rgba(0, 0, 0, 0)',}});
  factory = Bodies.rectangle(sceneWidth/2, sceneHeight-(0.3125*window.innerHeight+25), 1000, 50,
    {
      isStatic: true,
      render: {
        fillStyle: 'rgba(0, 0, 0, 0)',
        /*sprite: {
          texture: 'https://static.igem.wiki/teams/4757/wiki/fabrik.png',
          xScale: (0.25*window.innerHeight)/4279*2.5,
          yScale: (0.25*window.innerHeight)/4279*2.5
        }*/
      }
    }
  )

  Composite.add(engine.world, [wallDown, wallLeft, wallRight, wallUp, factory]);
  Engine.update(engine);
}


function activateGravity() {
  engine.world.gravity.y = 1;
}



function secondStage() {
  triangleLeft = Bodies.fromVertices(sceneWidth, sceneHeight/1.25-200, [ { "x":0, "y":0 }, { "x":0, "y":400 }, { "x":-750, "y":400}], {isStatic: true, render: {
         fillStyle: 'rgba(0, 0, 0, 0)',
    }});

  triangleRight = Bodies.fromVertices(0, sceneHeight/1.25-200, [ { "x":0, "y":0 }, { "x":0, "y":400 }, { "x":750, "y":400 }], {isStatic: true, render: {
         fillStyle: 'rgba(0, 0, 0, 0)',
    }});

  Composite.add(engine.world, [triangleLeft, triangleRight]);
  Matter.World.remove(engine.world, wallDown);

  Events.on(engine, "collisionStart", ({pairs}) => {
    pairs.forEach(({ bodyA, bodyB}) => {
      if (particles1.includes(bodyA)) {
        if (bodyB === factory) {
          let a = particles1.indexOf(bodyA);
          Matter.World.remove(engine.world, particles1[a]);
        }
      }
      else if (particles2.includes(bodyA)) {
        if (bodyB === factory) {
          let a = particles2.indexOf(bodyA);
          Matter.World.remove(engine.world, particles2[a]);
        }
      }
      else if (particles1.includes(bodyB)) {
        if (bodyA === factory) {
          let a = particles1.indexOf(bodyB);
          Matter.World.remove(engine.world, particles1[a]);
        }
      }
      else if (particles2.includes(bodyB)) {
        if (bodyA === factory) {
          let a = particles2.indexOf(bodyB);
          Matter.World.remove(engine.world, particles2[a]);
        }
      }
      else if (particles3.includes(bodyA)) {
        if (bodyB === factory) {
          let a = particles3.indexOf(bodyA);
          Matter.World.remove(engine.world, particles3[a]);
        }
      }
      else if (particles4.includes(bodyA)) {
        if (bodyB === factory) {
          let a = particles4.indexOf(bodyA);
          Matter.World.remove(engine.world, particles4[a]);
        }
      }
      else if (particles3.includes(bodyB)) {
        if (bodyA === factory) {
          let a = particles3.indexOf(bodyB);
          Matter.World.remove(engine.world, particles3[a]);
        }
      }
      else if (particles4.includes(bodyB)) {
        if (bodyA === factory) {
          let a = particles4.indexOf(bodyB);
          Matter.World.remove(engine.world, particles4[a]);
        }
      }
      else if (particles5.includes(bodyA)) {
        if (bodyB === factory) {
          let a = particles5.indexOf(bodyA);
          Matter.World.remove(engine.world, particles5[a]);
        }
      }
      else if (particles6.includes(bodyA)) {
        if (bodyB === factory) {
          let a = particles6.indexOf(bodyA);
          Matter.World.remove(engine.world, particles6[a]);
        }
      }
      else if (particles5.includes(bodyB)) {
        if (bodyA === factory) {
          let a = particles5.indexOf(bodyB);
          Matter.World.remove(engine.world, particles5[a]);
        }
      }
      else if (particles6.includes(bodyB)) {
        if (bodyA === factory) {
          let a = particles6.indexOf(bodyB);
          Matter.World.remove(engine.world, particles6[a]);
        }
      }
    });
  });
  // Engine.update(engine);
}
